summaryrefslogtreecommitdiffstats
path: root/kplato/kptresourceview.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:12:30 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:12:30 -0600
commit11191ef0b9908604d1d7aaca382b011ef22c454c (patch)
treed38f0ccd8bfcc9756f5cfc42fb2ad1dad351e6aa /kplato/kptresourceview.cc
parentc9cb4f487428aad5d8cda5e3a4b9ad87390d7e54 (diff)
downloadkoffice-11191ef0b9908604d1d7aaca382b011ef22c454c.tar.gz
koffice-11191ef0b9908604d1d7aaca382b011ef22c454c.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kplato/kptresourceview.cc')
-rw-r--r--kplato/kptresourceview.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/kplato/kptresourceview.cc b/kplato/kptresourceview.cc
index d596ff44..40d4b7c9 100644
--- a/kplato/kptresourceview.cc
+++ b/kplato/kptresourceview.cc
@@ -268,7 +268,7 @@ protected:
p->translate( rleft, crtop );
//kdDebug()<<k_funcinfo<<"paintBranches: "<<current->i->text(0)<<endl;
- current->i->paintBranches( p, tqcolorGroup(), treeStepSize(),
+ current->i->paintBranches( p, colorGroup(), treeStepSize(),
rtop - crtop, r.height() );
p->restore();
}
@@ -362,8 +362,8 @@ public:
TQDate date;
};
-TQSize ResourceView::tqsizeHint() const {
- return tqminimumSizeHint(); // HACK: koshell splitter tqminimumSize problem
+TQSize ResourceView::sizeHint() const {
+ return minimumSizeHint(); // HACK: koshell splitter minimumSize problem
}
ResourceView::ResourceView(View *view, TQWidget *parent)